@@ -7,14 +7,14 @@ import pkg_resources
 def install(package):
     subprocess.check_call([sys.executable, "-m", "pip", "install", package])
 
-try:
+# try:
+#
+#     import pixplot
+#
+# except BaseException as e:
+#     install('pixplot')
+#     import pixplot
+#
+#     print("Success installing pixplot_notebook packages:)")
 
-    import pixplot
-
-except BaseException as e:
-    install('pixplot')
-    import pixplot
-
-    print("Success installing pixplot_notebook packages:)")
-
-__version__ = pkg_resources.get_distribution('pixplot').version
\ No newline at end of file
+__version__ = pkg_resources.get_distribution('JATA').version
\ No newline at end of file
